#!/bin/bash
#
# Source : http://haproxy.1wt.eu/download/1.3/src/haproxy-1.3.20.tar.gz
# Maintainer : Son|c <emmanuel.bailleul@cegetel.net>
#


#------------------( Set Package Variables )


soft='haproxy'
softversion='1.3.20'
packageversion='64.1'


#------------------( Set Architecture Variables )

arch='i486'
cpu='i686'


#------------------( Set Architecture Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Prepare The Work Area And Source Package )


cd $buildir
rm -f {$dest,$dest.dep,$dest.md5,$dest.tgz,$package,$package.md5,$src} 1>/dev/null 2>&1
tar -xvzf $srcpkg
mkdir -p $dest


#------------------( Set Build Ownerships, Permissions and CFLAGS )


    chown -R root:root . 
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#export CFLAGS="-O2 -march=$arch -mtune=$cpu" 
#export CXXFLAGS="$CFLAGS"

##------------------( Zenify Makefile )
#
#cd $src
#sed -i '/CPU_CFLAGS.generic\ /a CPU_CFLAGS.zen = -O2 -march=i486 -mtune=i686' Makefile


#------------------( Make and Install Software )
cd $src
make TARGET=linux26 CPU=i686 USE_PCRE=1

#------------------( Clean things )

mkdir -p $dest/usr/sbin
mkdir -p $dest/etc/haproxy
mkdir -p $dest/etc/rc.d/desc
mv haproxy $dest/usr/sbin

#------------------( Create startup script )

cat << "EOF" > $dest/etc/rc.d/rc.haproxy.new
#!/bin/bash
#
## init script for haproxy

haproxy_start() {
        if [ -x /usr/sbin/haproxy ]; then
                echo -n "Starting haproxy :  "
                echo "/usr/sbin/haproxy -f /etc/haproxy/haproxy.conf -D"
                /usr/sbin/haproxy -f /etc/haproxy/haproxy.conf -D 2>/dev/null
        fi
}

haproxy_stop() {
        killall haproxy
}

haproxy_restart() {
        sh $0 stop
	sleep 1
        sh $0 start
}

case "$1" in
        'start')
                haproxy_start
                ;;
        'stop')
                haproxy_stop
                ;;
        'restart')
                haproxy_restart
                ;;
        *)
                echo "usage $0 start|stop|restart"
esac
EOF
chmod 644 $dest/etc/rc.d/rc.haproxy.new

mkdir $dest/etc/rc.d/desc.d
echo haproxy:Advanced Load Balancing daemon:haproxy > $dest/etc/rc.d/desc.d/haproxy.txt
chown -R root.root $dest/etc/rc.d

#------------------( Copy example config files )

cp examples/url-switching.cfg $dest/etc/haproxy/haproxy.conf.new
cp -a examples/errorfiles $dest/etc/haproxy/

#------------------ ( Create doinst.sh file )
mkdir $dest/install
echo "config() {
  NEW=\"\$1.new\"
  OLD=\"\$1\"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; then # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}
config etc/rc.d/rc.haproxy
config etc/haproxy/haproxy.conf" > $dest/install/doinst.sh

chmod 755 $dest/install/doinst.sh

#------------------ Strip Executables (Comment out these lines if debugging info is needed) )

cd $dest
chown -R root:root $dest
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#------------------( Copy and strip man page )

mkdir -p $dest/usr/man/man1
mv $src/doc/haproxy.1 $dest/usr/man/man1
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

#
# add 'default' files
#
mkdir -p $dest/usr/doc/$soft-$softversion
cd $src
cp -a \
CHANGELOG CONTRIB LICENSE README ROADMAP SUBVERS VERDATE VERSION TODO doc/* examples \
tests $dest/usr/doc/$soft-$softversion

#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create and Install The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
    |-----handy-ruler------------------------------------------------------|
haproxy: Very fast high availability and load balancing daemon
haproxy:
haproxy: HAProxy is a free, very fast and reliable solution offering high
haproxy: availability, load balancing, and proxying for TCP and HTTP-based
haproxy: applications. It is particularly suited for web sites crawling
haproxy: under very high loads while needing persistence or Layer7
haproxy: processing
haproxy: 
haproxy: 
haproxy: 
haproxy:
EOF


#------------------( Create The *.dep File )


cd $dest
depfinder $dest > $buildir/$package.dep

#------------------( Compress The Package And Clean Up The Work Area )

cd $dest
makepkg -l n -c n $dest.txz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
rm -f $package.md5
md5sum $package.txz > $package.md5

# Create source file
echo "http://haproxy.1wt.eu/download/1.3/src/haproxy-1.3.20.tar.gz" > $package.src
echo "http://download.zenwalk.org/people/emmanuel/$soft-$softversion/build-$soft.sh" >> $package.src
